import { Dispatch, SetStateAction, ReactNode } from 'react';
import Client, { OGIT } from '@hiro-graph/client';
import { ColorDefinitionValuesEnum, HiroColors, HiroPartialTheme } from '../../types';
export declare enum ViewType {
    overview = "OVERVIEW",
    graphView = "GRAPH_VIEW"
}
export declare enum FilterValue {
    UNDEPLOYED = "undeployed",
    DEPLOYED_TO_VALIDATE = "deployedToValidate",
    DEPLOYED_TO_LIVE = "deployedToLive"
}
export declare type Widgets = 'WelcomeConversion' | 'WelcomeTeaching' | 'TeachingSessions' | 'ConversionSessions' | 'TopTeachingContributors' | 'TopConverters' | 'StatisticTeaching' | 'StatisticConversion' | 'YourKis';
export declare type ButtonType = 'primary' | 'secondary';
export declare type DataTimeseriesName = 'TotalKIs' | 'AutomatedTasks' | 'TopContributors' | 'AutomationRate.Daily' | 'AutomationRate.Monthly';
export interface CircleColor {
    color: HiroColors;
    greyScale: ColorDefinitionValuesEnum;
}
export interface StatisticData {
    title: string;
    differenceText: string;
    whatItIs: string;
    howToImprove: string;
    angle: number;
    valueText: string;
    valueColor: CircleColor;
    backgroundColor: CircleColor;
    error: boolean;
    errorText: string;
    viewType?: ViewType;
}
export interface ViewData {
    action: () => void;
    title: string;
}
export interface ViewContextValue {
    activeView: string;
    setView: Dispatch<SetStateAction<string>>;
}
/**
 * Basic Widget config
 */
export interface BaseWidgetConfig {
    size?: string | number;
    title: string;
    as: Widgets;
}
/**
 * Advanced Widget config with automatic data loading
 */
export interface Me {
    id: string;
    accountId: string;
    email: string;
    displayName: string;
    roles: string[];
}
export interface WidgetProvider {
    openApp: (appId: string, options: any) => void;
    selectMe: () => Me;
    selectAppsIds: () => {
        [key: string]: string;
    };
    getEnvUrls: () => {
        [key: string]: string;
    };
}
export interface DashboardConfig {
    theme: HiroPartialTheme;
    widgets: Record<string, WidgetConfig>;
}
/**
 * Widgets
 */
export interface WelcomeConversionWidgetConfig extends BaseWidgetConfig {
    as: 'WelcomeConversion';
}
export interface WelcomeTeachingWidgetConfig extends BaseWidgetConfig {
    as: 'WelcomeTeaching';
}
export interface TeachingSessionsWidgetConfig extends BaseWidgetConfig {
    as: 'TeachingSessions';
}
export interface ConversionSessionsWidgetConfig extends BaseWidgetConfig {
    as: 'ConversionSessions';
}
export interface TopContributorsWidgetConfig extends BaseWidgetConfig {
    as: 'TopTeachingContributors';
}
export interface TopConvertersWidgetConfig extends BaseWidgetConfig {
    as: 'TopConverters';
}
export interface StatisticTeachingWidgetConfig extends BaseWidgetConfig {
    as: 'StatisticTeaching';
}
export interface StatisticConversionWidgetConfig extends BaseWidgetConfig {
    as: 'StatisticConversion';
}
export declare type WidgetConfig = WelcomeConversionWidgetConfig | WelcomeTeachingWidgetConfig | TeachingSessionsWidgetConfig | ConversionSessionsWidgetConfig | TopContributorsWidgetConfig | TopConvertersWidgetConfig | StatisticConversionWidgetConfig | StatisticTeachingWidgetConfig;
export interface WidgetProps {
    as: Widgets;
}
export interface OgitSession extends OGIT.SafeNode {
    'ogit/title'?: string;
    '/teaching_issue_subject'?: string;
    '/teaching_step_progress'?: string;
    '/teaching_ki_progress'?: string;
    '/teaching_ownerId'?: string;
    '/teaching_conversion_ownerId'?: string;
    '/teaching_is_handedover'?: string;
    '/teaching_rooms'?: string;
    '/teaching_rooms_completed'?: string;
    '/teaching_steps'?: string;
    '/teaching_steps_deployed'?: string;
    'ogit/Knowledge/archived': string;
}
/**
 * Sessions Widgets
 */
export interface ProgressBarProps {
    progress: number;
}
export interface ProgressBarChunkProps extends ProgressBarProps {
    active?: boolean;
}
export interface ProgressSessionData {
    value: number;
    completed: number;
    total: number;
}
export interface OriginNodeData {
    name: string;
    url: string;
}
export interface SessionData {
    id: string;
    name: string;
    knowledgeOwner: string;
    originNodeHref?: OriginNodeData | null;
    progress: null | ProgressSessionData;
    actions: ReactNode[];
    descriptionActions?: ReactNode[];
}
export interface SessionListData {
    title: string;
    goToAction: Function;
    sessions: SessionData[];
    loading: boolean;
    error: boolean;
}
export declare type QueryOptionsProvider = (accountId: string) => string[];
export declare type SessionHandler = (client: Client, openApp: Function, appIds: string[], me: string) => (session: OgitSession) => Promise<SessionData>;
/**
 * Top Contributors Widget
 */
export interface ContributorProps {
    userId: string;
    ranking: number;
    count: number;
    avatarUrl: string;
}
export declare type ContributorColumns = Array<ContributorProps[]>;
export declare type ContributorStats = [string, number];
/**
 * Your KIs Widget
 */
export interface KiStats {
    validation: number;
    deployed: number;
    undeployed: number;
    total: number;
}
export interface CountsData {
    counts: KiStats;
    loading: boolean;
    error: boolean;
}
export interface KiRowProps {
    title: ReactNode;
    value: number;
    description?: ReactNode;
    action: Function;
    primary?: boolean;
}
/**
 * Widget Content Loader
 */
export interface WidgetContentLoaderRenderProps {
    primary: string;
    secondary: string;
    index: number;
}
